Struct Cmd
Source #[repr(C)]
pub struct Cmd {
pub cmd_str: *const c_char,
pub help_str: *const c_char,
pub cmd_callback: CmdCallback,
pub availability_mask: u8,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.